function [Gamma,k_vec] = func_Gamma_values(L,n)
% Code to calculate the connection coefficients for a bounded interval
% The variable Gamma will have (L-1) columns for x = 1,2,...,L-1
% The variable k_vec will give the index order k for Gamma^n_k
% L is the wavelet order
% n is the derivative order
% p is a vector of wavelet filter coefficients

p = func_calc_filter_coefs(L);

%--------------------------------------------------------------------------
% calculate the Gamma^n(L-1) values.  
% Final order is from k = -(L-2) -> (L-2)
[Gamma_Lm1] = func_calc_Gamma_Lminus1(L,n,p);

%--------------------------------------------------------------------------
% calculate the Q_tilde matrix needed for solving Gamma(x) for 1<x<L-2
% this matrix should me (L-2)^2 x (L-2)^2
[Q_tilde] = func_calc_Qtilde_matrix(L,n,p);

%--------------------------------------------------------------------------
% calculate the d vector
% this vector should be (L-2)^2 long
[d] = func_calc_d_vector(L,n,p,Gamma_Lm1);

%--------------------------------------------------------------------------
% calculate the theta1 values
% this vector should be (L-1) long
[theta1] = func_calc_theta1_vector(L,n,p);

%--------------------------------------------------------------------------
% calculate the Gamma values at x = 1,2,...,L-2
% this vector should be (L-2)^2 long
[Gamma_X] = func_calc_Gamma_X(L,n,p,Gamma_Lm1,Q_tilde,d,theta1);

%--------------------------------------------------------------------------
% break up the Gamma_X vector so that it is properly indexed with respect
% to Gamma_Lm1
Gamma = zeros(length(Gamma_Lm1),(L-1));
k_vec = (-(L-2):(L-2))';

for II = 1:(L-2)
    k_vals = ((-(L-2)+II):(II-1))';
    row_start = find(k_vec == k_vals(1));
    row_stop = find(k_vec == k_vals(end));
    Gamma(row_start:row_stop,II) = Gamma_X((II-1)*(L-2) + (1:(L-2)));
end
Gamma(:,end) = Gamma_Lm1;
