function [gamma_val]=func_calc_Gamma_Lminus1(L,n,p)

%This function calculates the values of Gamma^n_k(L-1)


%--------------------------------------------------------------------------
% calculate the D matrix, as per the equation after (11) in T.Zhang et al.

for LL = 1:L-1
    for MM = 1:L-1
        d_temp = 0;
        for II = 0:L-1
            for JJ = 0:L-1
                d_index = 2*(LL-1)+II-JJ;
                
                if (d_index == (MM-1))
                    d_temp = d_temp + p(II+1)*p(JJ+1);
                end
                if (d_index == -(MM-1))&(d_index ~= 0)
                    d_temp = d_temp + (-1)^n*p(II+1)*p(JJ+1);
                end
                clear d_index
            end
        end
        D(LL,MM) = 2^(n-1)*d_temp;
    end
end

%--------------------------------------------------------------------------
% The solution space is given by the eigenvector associated with the
% eigenvalue equal to 1 (two equations below (11) in Zhang)
[v,d] = eig(D);
d = diag(d);
temp = find((d > 0.9999) & (d < 1.0001));
if (max(size(temp))>1) | (min(size(temp)) == 0)
    keyboard        %something is wrong
end
eigVec = v(:,temp);
clear temp

%--------------------------------------------------------------------------
% Normalize the eigenvector according to the moment equation
LHS = 0;
count = 0;
for KK = 0:(L-2)
    count = count + 1;
    LHS = LHS + KK^n*eigVec(count);
end

if n>0
    RHS = factorial(n)/2;
elseif n==0
    RHS = factorial(n);
else
    keyboard
end

scaling_factor = RHS/LHS;
gamma_val_temp = scaling_factor*eigVec;

%--------------------------------------------------------------------------
% check for round-off error on n=0 case
if n == 0
    gamma_val_temp(1) = 1;
    for II = 1:length(gamma_val_temp);
        if abs(gamma_val_temp(II)) < 1e-15
            gamma_val_temp(II) = 0;
        end
    end
end

%--------------------------------------------------------------------------
% build the whole vector from k = -(L-2) -> L-2 using condition (55) from
% Chen et. al

if (floor(n/2)) == (ceil(n/2))
    gamma_val = [flipud(gamma_val_temp);gamma_val_temp(2:end)];
else
    gamma_val = [-flipud(gamma_val_temp);gamma_val_temp(2:end)];
end
