function [soluSpace] = func_calc_solution_space(eigVec,admis_index,xVec,jVec,kVec,L)
% This function compiles a matrix of all the possible connection
% coefficient index combinations with the associated eigenvectors.  This
% makes the book-keeping easier in the following steps.  

% The matrix is called soluSpace; the first three columns are the x, j, k 
% values, and the remaining columns are the eigenvector coefficients which
% correspond to these indexes.

% An important thing to note is the "backfilling" that needs to be done.
% While there is only (L-2)^3 unknowns for x=1,2,...,(L-2), there are a
% number non-zero coefficients that arise from Eqn (112) that need to be
% included for the moment equations to be correct.  This is done below.

count = 0;
numVec = size(eigVec,2);        % number of vectors defining solution space
soluSpace = zeros(3+numVec);

% Set up the x, j, k index values as the first three columns
for XX = 1:length(xVec)
    for JJ = 1:length(jVec)
        for KK = 1:length(kVec)
            count = count + 1;
            xVal = xVec(XX);
            jVal = jVec(JJ);
            kVal = kVec(KK);
            soluSpace(count,1:3) = [xVal,jVal,kVal];
        end
    end
end

% fill in the eigenvector coefficients one vector at a time
for II = 1:size(soluSpace,1)
    xVal = soluSpace(II,1);
    jVal = soluSpace(II,2);
    kVal = soluSpace(II,3);
    
    if (abs(jVal)>=(L-1))|(abs(kVal)>=(L-1))|(abs(jVal-kVal)>=(L-1))
        % condition from Eqn (110)
        soluSpace(II,4:end) = zeros(1,numVec);
        
    elseif ((xVal-jVal)<=0)|((xVal-kVal)<=0)|(xVal<=0)
        % condition from Eqn (111)
        soluSpace(II,4:end) = zeros(1,numVec);
        
    elseif ((xVal-jVal)>=(L-1))|((xVal-kVal)>=(L-1))|(xVal>=(L-1))
        % condition from Eqn (112) -> the "backfilling"
        xVal = L-1;
        temp = find((admis_index(:,1) == xVal) & (admis_index(:,2) == jVal)&(admis_index(:,3) == kVal));
        if min(size(temp)) ~= 0
            soluSpace(II,4:end) = eigVec(temp,:);
        end
        clear temp
        
    else
        temp = find((admis_index(:,1) == xVal) & (admis_index(:,2) == jVal)&(admis_index(:,3) == kVal));
        if min(size(temp)) ~= 0
            soluSpace(II,4:end) = eigVec(temp,:);
        end
        clear temp
    end
end
